/* 
clean_data.do
This do file creates variables used in the main analysis for "Health, Human Capital and Domestic Violence" by Papageorge et al. ()2019). 

Last updated: 10/07/2019. 
*/

clear all
#delimit; 

use "$startdir\Estimation\Stata\Datasets\Raw Data\RawData.dta", clear; 



******* Generate & label variables ; 
* marital status; 
label define married 
1 "Legally Common-law married" 
2 "Not married but living with partner" 
3 "Widowed" 
4 "Divorced Annulled" 
5 "Separated" 
6 "Never married" 
7 "Other" 
-1 "NA (Skipped)"
-7 "Refusal"
-8 "Don't Know"
-9 "Missing";
label values marstat married;
label values mar_sd married;
replace marstat=. if marstat<0; 
replace mar_sd=. if mar_sd<0; 

* race; 
label define race 
	1 "White(Non-Hispanic)"
    2 "White(Hispanic)"           
    3 "Black (Non-Hispanic)"                  
    4 "Black (Hispanic)"
    5 "Other (Hispanic)"           
    6 "Asian/Pacific Islander"     
    7 "Ntv Amer/Alaskan"           
    8 "Other"  ;   
label values race race;
tab race ;

* income & education;  
label define incomemo
	1 "500 or less"
    2 "501-1000"
    3 "1001-1500"
    4 "1501-2000"
    5 "2001-2500"
    6 "2501-3000"
    7 "3001-6250"
    8 "> 6250"
    -1 "NA (Skipped)"
    -7 "Refusal"
    -8 "Don't know"
    -9 "Missing"; 
label values inc_sd incomemo; 
label values incmsd incomemo; 
replace inc_sd=. if inc_sd<0;
replace incmsd=. if incmsd<0;

gen incomemonthly = inc_sd if visit==1; 
replace incomemonthly = incmsd if visit>1;  
label values incomemonthly incomemo; 

label define incomeyr 
	1 "Yearly income 6000 or less"              
    2 "Yearly income 6001-12000"               
    3 "Yearly income 12001-18000"              
    4 "Yearly income 18001-24000"              
    5 "Yearly income 24001-30000"              
    6 "Yearly income 30001-36000"              
    7 "Yearly income 36001-75000"              
    8 "Yearly income $>$ 75000"                   
    -1 "NA (Skipped)"              
    -7 "Refusal"                   
    -8 "Don't know"                
    -9 "Missing"; 
label values income incomeyr; 
replace income=. if income<0; 

gen incomeco = income; 
replace incomeco = 6 if income==7 | income==8; 
label define incomecoyear
	1 "Yearly income $<$ 6000"              
    2 "Yearly income 6001-12000"               
    3 "Yearly income 12001-18000"              
    4 "Yearly income 18001-24000"              
    5 "Yearly income 24001-30000"              
    6 "Yearly income $>$ 30000" ;
label var incomeco incomecoyear; 

label define employed 
	1 "Employed"
	2 "Not employed"; 
label values employ employed; 
replace employ=. if employ<0; 

* risky behavior; 
label define drinks 
	0 "Abstainer"
	1 "Light (<3 drinks/wk)"
	2 "Moderate (3-13 drinks/wk)"
	3 "Heavier (>=14 drinks/wk)"
	-1 "NA (Skipped)"              
    -7 "Refusal"                   
    -8 "Don't know"                
    -9 "Missing"; 
label values drinkgrp drinks; 
replace drinkgrp=. if drinkgrp<0; 

label define smoke 
	0 "Never smoker"
	1 "Current smoker"
	2 "Former smoker (generally, smkhist>0 & cursmoke==0)";
label values smkgrp smoke; 

label define basesexa 
	1 "0 or no partners"
	2 "1 to 4 partners"
	3 "5 to 10 partners"
	4 "11 to 100 partners"
	5 "More than 100 partners"
	-1 "NA (Skipped)"              
    -7 "Refusal"                   
    -8 "Don't know"                
    -9 "Missing"; 
label values basesex basesexa; 
replace basesex=. if basesex<0; 

* education; 
label define education 
	1 "No schooling"
    2 "Grades 1-6"
    3 "Grades 7-11"
    4 "Completed high school"
    5 "Some college"
    6 "Completed 4 years of college"
    7 "Attended/Completed graduate school"
    -1 "NA (Skipped)"
    -7 "Refusal"
    -8 "Don't know"
    -9 "Missing";
label values eductn education;
replace eductn=. if eductn<0; 

gen lths=(eductn==1|eductn==2|eductn==3); 
replace lths=. if eductn==.; 
label var lths "Less than high school"; 

gen hsgrad=(eductn==4);
replace hsgrad=. if eductn==.;
label var hsgrad "High school grad";  

gen somecollege=(eductn==5);
replace somecollege=. if eductn==.;
label var somecollege "Some college"; 

gen collegegrad=(eductn==6|eductn==7); 
replace collegegrad=. if eductn==.; 
label var collegegrad "College grad"; 

* health & health outcomes; 
label define therapy
	0 "No therapy"
	1 "Mono therapy"
	2 "Combination therapy"
	3 "HAART"
	4 "HAART (HU/ddI defined)"; 
label values thrpyone therapy; 
label values thrpyvone therapy; 
label values thrpy therapy; 
label values thrpyv therapy; 

label define hivstat 
	1 "Negative"
	2 "Positive"
	4 "Converter";
label values status hivstat; 



* yes/no questions- violence; 
label define yesno
	 1 "Yes"
	 2 "No"
	 -1 "NA (Skipped)"
	 -7 "Refusal"
	 -8 "Don't know"
	 -9 "Missing";
	 
label values phyvps yesno; 	/* physical violence ever 1st visit only */ 
label values pso_ps yesno; 	/* physical violence by intimate partner 1st visit only */
label values sxabps yesno;  /* sex abuse ever 2nd visit+ */ 
label values sso_ps yesno;  /* sex abuse by intimate partner 1st visit only */
label values hurtps yesno; 	/* partner ever threaten to kill you 1st visit only*/
label values leavps yesno; 	/* partner ever prevent you from leaving house 1st visit only */
label values frndps yesno; 	/* partner kept you from seeing friends 1st visit only */
label values phonps yesno; 	/* partner kept you from using phone 1st visit only */
label values kjobps yesno; 	/* partner ever kept you from getting job 1st visit only */
label values cedups yesno; 	/* partner ever kept you from continuing education 1st visit only*/
label values medaps yesno; 	/* partner ever kept you from medicine 1st visit only */
label values afsops yesno; 	/* feel afraid of partner 1st visit*/
label values soklps yesno;	/* think partner may kill you 1st visit*/
label values afhmps yesno; 	/* afraid to go home 1st visit*/
label values sapsps yesno;	/* ever forced sex contact w/ HIV + individual 1st visit only*/ 
label values smasps yesno;  /* sexual abuse by mother stopped (visit 1) */
label values sdasps yesno;	/* sexual abuse by father stopped (visit 1) */
label values ssfsps yesno; 	/* sexual abuse by stepfather stopped (visit 1) */
label values ssssps yesno;  /* sexual abuse by sibling stopped (visit 1) */
label values smpsps yesno;	/* sexual abuse by mom's bf stopped (visit 1) */	
label values sorsps yesno;  /* sexual abuse by other relative stopped (visit 1) */		
label values ssosps yesno; 	/* sexual abuse by intimate partner stopped (visit 1) */	
label values sfrsps yesno; 	/* sexual abuse by friend stopped (visit 1) */	
label values sacsps yesno; 	/* sexual abuse by aquaintance stopped (visit 1) */	
label values sstsps yesno; 	/* sexual abuse by stranger stopped (visit 1) */
label values so1sps yesno; 	/* sexual abuse by other1 stopped (visit 1) */
label values so2sps yesno;  /* sexual abuse by other2 stopped (visit 1) */
label values so3sps yesno;  /* sexual abuse by other3 stopped (visit 1) */
label values sprtps yesno; 	/* sexual abuse by partner/spouse SLV */ 
label values ssprps yesno; 	/* sexual abuse by partner/spouse stopped */ 
label values thrtps yesno; 	/* partner threaten to kill you SLV */
label values pvhsps yesno; 	/* partner prevented from leaving/entering house SLV */
label values pvfrps yesno;	/* partner prevented participant from seeing friends SLV */
label values pvclps yesno;	/* partner prevented participant from making phone calls SLV*/
label values pvjbps yesno;	/* partner prevented participant from getting/keeping job SLV */
label values pvedps yesno; 	/* partner prevented participant from continuing edu SLV */ 
label values pvmdps yesno;	/* partner prevented participant from seeking medical attention SLV  */ 
label values afptps yesno; 	/* feel afraid of partner visit 2+ */ 
label values tkilps yesno; 	/* participant feels parnter might try to kill her visit 2+ */ 
label values afhmps yesno; 	/* afriad to go home visit 2+*/ 
label values violps yesno; 	/* experienced serious physical violence SLV */ 
label values vqprps yesno;	/* will proceed with PV questions visit 2+ */ 
label values vprtps yesno; 	/* PV by partner/spouse SLV */ 
label values svprps yesno; 	/* PV by partner/spouse stopped */ 


* yes/no questions- relationship; 
label values lwspsd yesno; 	/* lives with spouse 1st visit only*/ 
label values hvsops yesno; 	/* currenlty in a relationshiop 1st visit */ 
label values inrlps yesno; 	/* currently in relationship w/ someone considered partner visit 2+ */ 


* yes/no questions- drug use; 
label values epotbh yesno; 	/* ever use marijuana/hash 1st visit only*/
label values cch_bh yesno; 	/* ever use crack, cocain, heroin */
label values injebh yesno;	/* injected drugs during past 6 mo */
label values sxpdbh yesno; 	/* ever had sex for drugs, money, shelter */ 

* yes/no questions- demographics, etc. ; 
label values chllps yesno; 	/* have living children under 18 */ 
label values ccarps yesno; 	/* child born/died or came/left since last visit */ 
label values cbrnps yesno;  /* given birth to any children since last visit */
label values clwyps yesno; 	/* child lives w/ you */ 
label values ccomps yesno; 	/* foster, step, adopted children came into care SLV */ 
label values clveps yesno; 	/* children under 17 left care SLV */ 
label values cdthps yesno; 	/* children have died since last visit */ 

label values lkidsd yesno; 	/* children live w/ participant 1st visit*/ 
label values lmalsd yesno; 	/* husband/male sex prtnr lives w/ participant */
label var lmalsd "Male partner lives with participant"; 
label values lfemsd yesno; 	/* female sex prtnr lives w/ participant */ 
label var lfemsd "Female partner lives with participant"; 
label values hcp6hc yesno; 
label var hcp6hc "Seen a health care provider SLV"; 
label values sdochc yesno; 
label var sdochc "Saw mostly same hcp SLV"; 

foreach var in lwspsd phyvps pso_ps sxabps sso_ps hurtps leavps frndps phonps kjobps 
			   cedups medaps hvsops afsops soklps afhmps epotbh cch_bh injebh sxpdbh
			   sapsps chllps ccarps cbrnps clwyps ccomps clveps cdthps sprtps ssprps 
			   thrtps pvhsps pvfrps pvclps pvjbps pvedps pvmdps inrlps afptps tkilps 
			   afhmps violps vqprps vprtps svprps lkidsd lmalsd lfemsd hcp6hc sdochc{;
	replace `var'=. if `var'<0; 
}; 
replace lmalsd=. if lmalsd==3; 
replace lfemsd=. if lfemsd==3; 


* time variables- violence; 
label define time 
	1 "Within past week"
	2 "More than a week ago, but within past month"
	3 "More than a month ago, but withi past 6 months"
	4 "More than 6 months ago, but within past year"
	5 "More than a year ago"
	-1 "NA (Skipped)"
	-7 "Refusal"
	-8 "Don't know"
	-9 "Missing";
label values whrtps time;	/* most recent time partner threatened to kill you 1st visit only */
label values wleaps time; 	/* most recent time partner prevented you from leaving house 1st visit only */
label values wfrnps time; 	/* most recent time partner prevented you from friends 1st visit only */
label values wphops time; 	/* most recent time partner not let you call 1st visit only  */
label values wkjops time; 	/* most recent time partner kept you from a job 1st visit only */
label values wcedps time; 	/* most recent time partner kept you from continuing education 1st visit only */
label values wmedps time; 	/* most recent time partner kept you from medicing 1st visit only */
label values wthtps time; 	/* most recent time partner threatened to hurt/kill visit 2+*/
label values wpvhps time; 	/* most recent time partner prevented from entering/leaving house visit 2+*/ 
label values wpvfps time; 	/* most recent time partner kept participant from friends */ 
label values wpvcps time; 	/* most recent time partner kept participant from making phone calls*/
label values wpvjps time; 	/* most recent time partner kept participant from getting/keeping job */
label values wpveps time; 	/* most recent time partner kept participant from edu */ 
label values wpvmps time; 	/* most recent time partner prevented participant from seeking medical attntn */ 

foreach var in whrtps wleaps wfrnps wphops wkjops wcedps wmedps wthtps wpvhps wpvfps wpvcps wpvjps wpveps wpvmps 
	futrps nvishc hdochc clinhc{;
	replace `var'=. if `var'<0; 
}; 

* health outcomes; 
label var futrps "Past week I was hopeful about the future"; 
label define pstwk
	1 "Rarely (lt 1 day)"
	2 "Some (1-2 days)"
	3 "Occasionally (3-4 days)" 
	4 "Most (5-7 days)";
label values futrps pstwk; 

label var deprps "Past week felt depressed"; 
label values deprps pstwk; 
replace deprps=. if deprps<0; 


* some people have multiple obs for same person/visit; 
* a lot of this is being driven by symptoms- make not missing by replacing with "mean";
foreach var in pso_ps phyvps vprtps violps
pmaops pmasps pdaops pdasps psfops psfsps psbops psbsps pmpops pmpsps porops porsps
psoops psosps pfrops pfrsps pacops pacsps pstops pstsps po1ops po2ops po3ops
phyvps pma_ps pda_ps psf_ps psb_ps por_ps vmomps vdadps vsbsps vmbpps vorlps 
pmasps pdasps psfsps psbsps porsps
syfvmh sydimh symlmh synumh sywlmh symtmh synsmh futrps {; 
* generates mean (ignores missing data);
bys wihsid visit: egen `var'mean = mean(`var'); 
* make sure that values are not different (and so mean will be a whole #); 
gen test = round(`var'mean) - `var'; 
assert test==0 | test==.;
bys wihsid visit: replace `var' = `var'mean if `var'==.;
drop `var'mean test; 
}; 



**** Construct variables outlined in concept sheet;
*** 1. Domestic Violence ;
** Sexual abuse by partner; 
* need to put visit 1 into same time frame as other visits; 
* assume that if sex abuse has not stopped or has stopped by age at visit - 1 they should have a 1;
* assume that if never report sex abuse by partner OR report it stopping more than 1 year ago, should have a 0;  
gen agediff = ageatvis - ssoops if ssosps==1; 
gen sexabuseprtnr = .; 
* first visit; 
replace sexabuseprtnr = 0 if sso_ps==2 | sqprps==-1;					/* never report being abused by partner OR never reported being sexually abused */
replace sexabuseprtnr = 0 if sso_ps==1 & (agediff >=1 & agediff!=.);  	/* report being abused by partner & it stopped more than one year ago */
* other visits; 
replace sexabuseprtnr = 0 if sxabps==2 | sprtps==2; 
* first visit; 
replace sexabuseprtnr = 1 if sso_ps==1 & (agediff<1 | ssosps==2) & visit==1;  
* other visits; 
replace sexabuseprtnr = 1 if sprtps==1 & visit !=1; 
drop agediff; 

*** Sex abuse by family member; 
** sex abuse by family ever; 
* construct age differences for each person asked about ;  
gen agediffmom = ageatvis - smaops if smasps==1; 		/*age - age mom sex abuse stopped if it has stopped*/
gen agediffdad = ageatvis - sdaops if sdasps==1; 		/*age - age dad sex abuse stopped if it has stopped*/
gen agediffstepdad = ageatvis - ssfops if ssfsps==1; 	/*age - age stepdad sex abuse stopped  if it has stopped */
gen agediffsibling = ageatvis - ssbops if ssssps==1;	/*age - age sibling sex abuse stopped if it has stopped */
gen agediffmombf = ageatvis - smpops if smpsps==1; 		/*age - age mom's bf sex abuse stopped if it has stopped */
gen agediffrel = ageatvis - sorops if sorsps==1; 		/*age - age other relative sex abuse stopped if it has stopped */
gen agediffprtnr = ageatvis - ssoops if ssosps==1; 		/*age - age partner sex abuse stopped if it has stopped */ 
gen agedifffrnd = ageatvis - sfrops if sfrsps==1; 		/*age - age friend sex abuse stopped if it has stopped */
gen agediffaqu = ageatvis - sacops if sacsps==1; 		/*age - age aquaintance sex abuse stopped if it has stopped */
gen agediffstrngr = ageatvis - sstops if sstsps==1; 	/*age - age stranger sex abuse stopped if it has stopped */
gen agediffother1 = ageatvis - so1ops if so1sps==1; 	/*age - age other (1) sex abuse stopped if it has stopped */
gen agediffother2 = ageatvis - so2ops if so2sps==1; 	/*age - age other (2) sex abuse stopped if it has stopped */
gen agediffother3 = ageatvis - so3ops if so3sps==1; 	/*age - age other (3) sex abuse stopped if it has stopped */

* for family, included mom, dad, stepdad, sibling, other relative; 
egen agedifffam = rowmin(agediffmom agediffdad agediffstepdad agediffsibling agediffrel);

gen sexabusefam = .; 
* sexabuse questions do not apply OR they were not abused by family OR they were but it stopped over 1 yr ago; 
replace sexabusefam = 0 if sqprps==-1 | (sma_ps==2 & sda_ps==2 & ssf_ps==2 & ssb_ps==2 & sor_ps==2) | (sqprps==1 & agedifffam >=1 & agedifffam!=.) & visit==1;  
replace sexabusefam = 0 if sxabps==2 | (sxabps==1 & smomps==2 & sdadps==2 & ssbsps==2 & smbpps==2 & sorlps==2 & sprtps==2) & visit!=1; 
* sexabuse stopped less than 1 yr ago OR has not stopped yet; 
replace sexabusefam = 1 if (agedifffam <1 | smasps==2 | sdasps==2 | ssfsps==2 | ssssps==2 | sorsps==2) & visit==1; 
replace sexabusefam = 1 if (smomps==1 | sdadps==1 | ssbsps==1 | smbpps==1 | sorlps==1 | sprtps==1) & visit!=1;

*** Sexual abuse; 
egen agediff = rowmin(agediff*); 	/* look at min age difference for anyone */ 

gen sexabuse = .; 
* sex abuse questions do not apply to individual OR they do but stopped over 1 yr ago;
replace sexabuse = 0 if sqprps==-1 | (sqprps==1 & agediff>=1 & agediff~=.) & visit==1; 
replace sexabuse = 0 if sxabps==2 & visit!=1; 
replace sexabuse = 1 if sxabps==1 & visit!=1;

* agediff < 1 or sex abuse with any person has not stopped ; 
replace sexabuse = 1 if sqprps==1 & (agediff <1 | smasps==2 | sdasps==2 | ssfsps==2 |ssssps==2 | smpsps==2 |
	sorsps==2 | ssoops==2 | sfrsps==2 | sacsps==2 | sstsps==2 | so1sps==2 | so2sps==2 | so3sps==2) & visit==1; 
drop agediff*; 


*** Phyical abuse by partner; 
* again, have to put visit 1 in same time frame as other visits; 
* =1 if violence hasn't stopped or stopped less than 1 year from visit; 
* =0 if violence never ocurred or stopped more than 1 year from visit; 
gen agediff = ageatvis - psoops if psosps==1; 
gen physabuseprtnr = .; 
* first visit; 
replace physabuseprtnr = 0 if pso_ps==2 | phyvps==2; 	/* never reported */
replace physabuseprtnr = 0 if pso_ps==1 & agediff>=1 & agediff!=.; 
* other visits; 
replace physabuseprtnr = 0 if vprtps==2 | violps==2; 
* first visit; 
replace physabuseprtnr = 1 if pso_ps==1 & (agediff<1 | psosps==2);
* other visits;  
replace physabuseprtnr = 1 if vprtps==1 & visit !=1; 
drop agediff; 

gen agediffmom = ageatvis - pmaops if pmasps==1; 
gen agediffdad = ageatvis - pdaops if pdasps==1; 
gen agediffstepdad = ageatvis - psfops if psfsps==1; 
gen agediffsib = ageatvis - psbops if psbsps==1; 
gen agediffmombf = ageatvis - pmpops if pmpsps==1; 
gen agediffrel = ageatvis - porops if porsps==1; 
gen agediffprtnr = ageatvis - psoops if psosps==1; 
gen agedifffriend = ageatvis - pfrops if pfrsps==1; 
gen agediffaq = ageatvis - pacops if pacsps==1; 
gen agediffstrngr = ageatvis - pstops if pstsps==1; 
gen agediffothr1 = ageatvis - po1ops if po1sps==1; 
gen agediffothr2 = ageatvis - po2ops if po2sps==1; 
gen agediffothr3 = ageatvis - po3ops if po3sps==1; 

egen agedifffam = rowmean(agediffmom agediffdad agediffstepdad agediffsib agediffrel); 

** Physical abuse by family; 
gen physabusefam = .; 
* 0 if never abused OR was abused but not by family member OR was abused by family member but stopped more than 1 year ago; 
* mother, father, step-father, sibling, other relative; 
replace physabusefam = 0 if phyvps==2 | (phyvps==1 & pma_ps==2 & pda_ps==2 & psf_ps==2 & psb_ps==2 & por_ps==2) | (phyvps==1 & agedifffam>=1 & agedifffam!=.) & visit==1;  
replace physabusefam = 0 if violps==2 | (phyvps==1 & vmomps==2 & vdadps==2 & vsbsps==2 & vmbpps==2 & vorlps==2 & vprtps==2) & visit!=1; 
* 1 if abused by family less than a year ago OR abuse has not stopped; 
replace physabusefam = 1 if agedifffam<1 | (pmasps==2 | pdasps==2 | psfsps==2 | psbsps==2 | porsps==2) & visit==1;  
replace physabusefam = 1 if (vmomps==1 | vdadps==1 | vsbsps==1 | vmbpps==1 | vorlps==1 | vprtps==1) & visit!=1; 

** Physical abuse; 
egen agediff = rowmin(agediff*); 
gen physabuse = .; 
* never report physical abuse OR do report it, but it was more than 1 year ago; 
replace physabuse = 0 if phyvps==2 | (phyvps==1 & agediff>=1 & agediff!=.) & visit==1; 
replace physabuse = 0 if violps==2 & visit!=1; 
replace physabuse = 1 if phyvps==1 & agediff<1 & visit==1; 
replace physabuse = 1 if violps==1 & visit!=1; 
 
** Coercion- includes feeling afraid of partner, thinking that partner may kill you, afraid to go home ; 
* again, have to put it in same time frame. 
* assume if coercion happened in last year, get a 1 else get a 0;
gen coercion = .;

/* in a relationship or not; 
replace coercion=0 if hvsops==2 & visit==1;  
replace coercion=0 if inrlps==2 & visit!=1; 
*/
* first visit; 
* never report coercion; 
replace coercion=0 if (hurtps==2 & leavps==2 & frndps==2 & phonps==2 & kjobps==2 & cedups==2 & medaps==2) & visit==1; 
* report it but not in last year; 
/* 
threat to kill, prevent from leaving the house, prevent from seeing friend, prevent from making a call 
prevent from getting a job, prevent from getting education, prevent from getting medicine */  
replace coercion=0 if (hurtps==1 & whrtps==5) | (leavps==1 & wleaps==5) | (frndps==1 & wfrnps==5) |
 (phonps==1 & wphops==5) | (kjobps==1 & wkjops==5) | (cedups==1 & wcedps==5) | (medaps==1 & wmedps==5);
replace coercion=1 if (hurtps==1 & whrtps<5) | (leavps==1 & wleaps<5) | (frndps==1 & wfrnps<5) | 
 (phonps==1 & wphops<5) | (kjobps==1 & wkjops<5) | (cedups==1 & wcedps<5) | (medaps==1 & wmedps<5); 
* other visits; 
replace coercion=0 if (thrtps==2 & pvhsps==2 & pvfrps==2 & pvclps==2 & pvjbps==2 & pvedps==2 & pvmdps==2) & visit!=1; 
replace coercion=1 if (thrtps==1 | pvhsps==1 | pvfrps==1 | pvclps==1 | pvjbps==1 | pvedps==1 | pvmdps==1) & visit!=1; 

 
** According to Cohen et al."domestic violence = physical or sexual abuse or coercion by an intimate partner or spouse";
gen dva = .;
replace dva = 0 if sexabuseprtnr==0 & physabuseprtnr==0 & coercion==0;  
replace dva = 1 if sexabuseprtnr==1 | physabuseprtnr==1 | coercion==1; 


** HIV treatment Dynamics; 
gen HAARTslv = .; 
replace HAARTslv = 1 if thrpy==3; 
replace HAARTslv = 0 if thrpy==0 | thrpy==1 | thrpy==2; 

gen HAARTatvis =.;
replace HAARTatvis = 1 if thrpyv==3;  
replace HAARTatvis = 0 if thrpyv==0 | thrpyv==1 | thrpyv==2; 

* ever on HAART; 
gen HAARTever=(HAARTslv==1 & visit==1); 
bys wihsid: replace HAARTever=1 if HAARTslv==1 | HAARTever[_n-1]==1; 
label var HAARTever "HAART ever"; 

** HIV status; 
gen positive=(status==2); 
replace positive=1 if status==4 & visit>=posvis; 
label var positive "HIV positive"; 


*** 2. Disease Dynamics Variables;
* time dummy variable; 
gen date2 = date(date, "MD19Y"); 
gen year = year(date2); 
* replace 20XX year - WIHS started in 1993 ; 
replace date2 = date(date, "MD20Y") if year<1993;  
replace year = year(date2); 
gen month = month(date2); 


* time of first hiv+ test; 
gen hivposdate0 = fpossc;
gen hivposmo = substr(hivposdate0,1,2); 
destring hivposmo, replace; 
replace hivposmo = . if hivposmo<0; 

gen hivposyr = substr(hivposdate0,3,2); 
destring hivposyr, replace; 
replace hivposyr = 1900 + hivposyr;  /* putting everything in YYYY format */

gen hivposdate = mdy(hivposmo, 1, hivposyr); /* date of first hiv+ test */
replace hivposdate = . if hivposmo<0 | hivposyr<1900; 
gen hivpostime = date2 - hivposdate; 


* create date of visit bins--> starts in Oct. 1994; 
gen dovbin = .;
replace dovbin = 1 if year==1994 | (year==1995 & month<=2); 
replace dovbin = 2 if year==1995 & month>=3 & month<=8;
replace dovbin = 3 if (year==1995 & month>=9) | (year==1996 & month<=2); 
replace dovbin = 4 if year==1996 & month>=3 & month<=8;
replace dovbin = 5 if (year==1996 & month>=9) | (year==1997 & month<=2); 
replace dovbin = 6 if year==1997 & month>=3 & month<=8;
replace dovbin = 7 if (year==1997 & month>=9) | (year==1998 & month<=2); 
replace dovbin = 8 if year==1998 & month>=3 & month<=8;
replace dovbin = 9 if (year==1998 & month>=9) | (year==1999 & month<=2); 
replace dovbin = 10 if year==1999 & month>=3 & month<=8;
replace dovbin = 11 if (year==1999 & month>=9) | (year==2000 & month<=2); 
replace dovbin = 12 if year==2000 & month>=3 & month<=8;
replace dovbin = 13 if (year==2000 & month>=9) | (year==2001 & month<=2); 
replace dovbin = 14 if year==2001 & month>=3 & month<=8;
replace dovbin = 15 if (year==2001 & month>=9) | (year==2002 & month<=2); 
replace dovbin = 16 if year==2002 & month>=3 & month<=8;
replace dovbin = 17 if (year==2002 & month>=9) | (year==2003 & month<=2); 
replace dovbin = 18 if year==2003 & month>=3 & month<=8;
replace dovbin = 19 if (year==2003 & month>=9) | (year==2004 & month<=2); 
replace dovbin = 20 if year==2004 & month>=3 & month<=8;
replace dovbin = 21 if (year==2004 & month>=9) | (year==2005 & month<=2); 
replace dovbin = 22 if year==2005 & month>=3 & month<=8;
replace dovbin = 23 if (year==2005 & month>=9) | (year==2006 & month<=2); 
replace dovbin = 24 if year==2006 & month>=3 & month<=8;
replace dovbin = 25 if (year==2006 & month>=9) | (year==2007 & month<=2); 
replace dovbin = 26 if year==2007 & month>=3 & month<=8;
replace dovbin = 27 if (year==2007 & month>=9) | (year==2008 & month<=2); 
replace dovbin = 28 if year==2008 & month>=3 & month<=8;
replace dovbin = 29 if (year==2008 & month>=9) | (year==2009 & month<=2); 
replace dovbin = 30 if year==2009 & month>=3 & month<=8;
replace dovbin = 31 if (year==2009 & month>=9) | (year==2010 & month<=2); 
replace dovbin = 32 if year==2010 & month>=3 & month<=8;
replace dovbin = 33 if (year==2010 & month>=9) | (year==2011 & month<=2); 
replace dovbin = 34 if year==2011 & month>=3 & month<=8;

* dovbin = 5 is the first one that HAART is available; 
gen dovbincenter = dovbin - 4; 

* year bins; 
gen yearbin = .;
replace yearbin = 1 if (year==1994 & month>=9) | (year==1995 & month<=8);
replace yearbin = 2 if (year==1995 & month>=9) | (year==1996 & month<=8); 
replace yearbin = 3 if (year==1996 & month>=9) | (year==1997 & month<=8);
replace yearbin = 4 if (year==1997 & month>=9) | (year==1998 & month<=8); 
replace yearbin = 5 if (year==1998 & month>=9) | (year==1999 & month<=8);
replace yearbin = 6 if (year==1999 & month>=9) | (year==2000 & month<=8); 
replace yearbin = 7 if (year==2000 & month>=9) | (year==2001 & month<=8);
replace yearbin = 8 if (year==2001 & month>=9) | (year==2002 & month<=8); 
replace yearbin = 9 if (year==2002 & month>=9) | (year==2003 & month<=8);
replace yearbin = 10 if (year==2003 & month>=9) | (year==2004 & month<=8); 
replace yearbin = 11 if (year==2004 & month>=9) | (year==2005 & month<=8);
replace yearbin = 12 if (year==2005 & month>=9) | (year==2006 & month<=8); 
replace yearbin = 13 if (year==2006 & month>=9) | (year==2007 & month<=8);
replace yearbin = 14 if (year==2007 & month>=9) | (year==2008 & month<=8); 
replace yearbin = 15 if (year==2008 & month>=9) | (year==2009 & month<=8);
replace yearbin = 16 if (year==2009 & month>=9) | (year==2010 & month<=8); 
replace yearbin = 17 if (year==2010 & month>=9) | (year==2011 & month<=8);

* year bin 3 is first one that HAART is available; 
gen yearbincenter = yearbin-2;



*** 3. Socioeconomic and Psychosocial Variables (control variables)
** socioeconomic variables; 
* dob; 
gen dateofbirth = date(dob, "MDY"); 
gen dobyear = year(dateofbirth);
label var dobyear "Year of birth";
gen dobmonth = month(dateofbirth);
label var dobmont "Month of birth"; 
gen dobday = day(dateofbirth); 
label var dobday "Day of birth"; 

** psychological well-being; 
/*physf (phys fn), rolef (role fn), enfat (energy/fatigue fn), soclf (social fn), cognf (cog fn), 
pain, emotl (emotional wellbeing), hlthp (health preception), qlindx (QOL index), cesd (depression score);*/


* pusd doesn't start until visit 9, so not super useful...;
gen nkidslt18 = nkidsd if visit==1; 
replace nkidslt18 = pu18sd if visit!=1; 
replace nkidslt18 = 0 if lkidsd==2 | nressd==0; 
replace nkidslt18=. if nkidslt18<0; 

gen kids = (nkidslt18>0 & nkidslt18!=.); 
replace kids = . if nkidslt18==.; 

bys wihsid: gen kidsbl1 = (lkidsd==1); 
bys wihsid: egen kidsbl = max(kidsbl1); 
label var kidsbl "Lives with kids at base line"; 
drop kidsbl1; 

** symptoms; 
* individual; 
rename syfvmh fever ;
label var fever "Symptom: Fever";
rename sydimh diarrhea;
label var diarrhea "Symptom: Diarrhea"; 
rename symlmh memoryprblm;
label var memoryprblm "Symptom: Memory problems";
rename synumh numbness;
label var numbness "Symptom: Numbness/tingling"; 
rename sywlmh weightloss; 
label var weightloss "Symptom: Weight Loss"; 
rename symtmh mentalconf; 
label var mentalconf "Symptom: Mental Confusion"; 
rename synsmh nightsweats;
label var nightsweats "Symptom: Night Sweats"; 


* replace 2=no, 1=yes to 0=no; 
foreach var in fever diarrhea memoryprblm numbness weightloss mentalconf nightsweats{; 
replace `var'=. if `var'<0; 
replace `var'=0 if `var'==2; 
}; 

keep  wihsid visit sexabuseprtnr physabuseprtnr physabusefam physabuse coercion /*afraidprtnr*/ sexabuse sexabusefam
	  vload cd4n cd4p date2 month year insurance incomeco drinkgrp cursmoke smkhist smkgrp potuse crackuse bsvisit thrpy thrpyv
	  cocuse heruse mdonuse mthause odrguse msex6mo fsex6mo eductn sexident hsgrad hivpostime
	  race cob dateofbirth dobyear dobmonth dobday dovbin outcdth lvismv kidsbl futrps
	  basepot basecch basemdon baseidu basenidu basesex basemsex basefsex paidsex lkidsd 
	  status status02 marstat employ ageatvis resid physf rolef enfat soclf cognf nkidslt18
	  pain emotl hlthp qlindx cesd thrpyone thrpyvone HAARTslv HAARTatvis HAARTever*
	  lths hsgrad somecollege collegegrad positive lmalsd lfemsd dva /*dvb dvc dvd*/ kids cd4nadir
	  fever diarrhea memoryprblm numbness weightloss mentalconf nightsweats
	  hcp6hc sdochc nvishc hdochc clinhc /*deprps*/ /*hivpostime*/ dovbincenter yearbin yearbincenter ; 


duplicates drop; 

 
* check- make sure only one person per visit; 
bys wihsid visit: gen personvisit=_n==1; 
tab personvisit; 
assert personvisit==1; 
drop personvisit; 


** make sure that if the variable is time invariant, it is entered for every observation; 
foreach var in race cob dateofbirth dobyear dobmonth dobday {;
	count if `var'==.; 
	bys wihsid: egen mean`var' = mean(`var'); 
	replace `var' = mean`var'; 
	drop mean`var'; 
};


*** variables used in regressions;  

* site; 
gen site = floor(wihsid/10000000);
label var site "Site"; 
label define location 
	1 "Bronx"
	2 "Brooklyn"
	3 "DC"
	4 "Los Angeles"
	5 "San Francisco" 
	6 "Chicago"; 
label values site location; 

* site dummies; 
gen sitebronx = (site==1); 
gen sitebrooklyn = (site==2); 
gen sitedc = (site==3); 
gen sitela = (site==4); 
gen sitesanfran = (site==5); 
gen sitechicago = (site==6); 

label var sitebronx "Bronx"; 
label var sitebrooklyn "Brooklyn"; 
label var sitedc "DC"; 
label var sitela "LA"; 
label var sitesanfran "San Francisco";
label var sitechicago "Chicago"; 

/*
gen ownhouse=(resid==1); 
replace ownhouse=. if resid==.; 
label var ownhouse "Own her house"; 
*/

gen marlivwithprtnr = (marstat==1 | marstat==2); 
replace marlivwithprtnr=. if marstat==.; 
label var marlivwithprtnr "Married/Live w/ prtnr"; 


tab marstat, gen(mar); 
rename mar1 married; 
label var married "Married"; 

rename mar2 livewithprtnr; 
label var livewithprtnr "Not married, lives with prtnr"; 

rename mar3 widowed; 
label var widowed "Widowed"; 

rename mar4 divorced; 
label var divorced "Divorced/Annuled"; 

rename mar5 separated; 
label var separated "Separated"; 

rename mar6 nevermarried; 
label var nevermarried "Never Married"; 

rename mar7 marstatother; 
label var marstatother "Other Marital Status"; 

gen liveswprtnr=(lmalsd==1|lfemsd==1 | married==1 | livewithprtnr==1); 
replace liveswprtnr=. if lmalsd==. & lfemsd==. & married==. & livewithprtnr==.;
label var liveswprtnr "Lives with Partner"; 


/*
gen bornus = (cob==1); 
replace bornus=. if cob==.; 
label var bornus "Born in the US"; 
*/

** age curvature; 
gen agesq=ageatvis*ageatvis; 
label var agesq "Age squared"; 
gen agecube = ageatvis*ageatvis*ageatvis;
label var agecube "Age cubed"; 
gen agequad = agecube*ageatvis;
label var agequad "Age quad"; 


** illicit drug use; 
gen druguse = (potuse==1 | crackuse==1 | cocuse==1 | heruse==1 | mdonuse==1 | odrguse==1);
replace druguse = . if (potuse==. & crackuse==. & cocuse==. & heruse==. & mdonuse==. & odrguse==.); 

gen harddrugs = (crackuse==1 | heruse==1 | mdonuse==1 | cocuse==1); 
replace harddrugs = . if (crackuse==. & heruse==. & mdonuse==. & cocuse==.);
label var harddrugs "Crack, Heroin, Methadone, or Coke"; 

gen cocainefull = (crackuse==1 | cocuse==1) ;
replace cocainefull = . if (crackuse==. & cocuse==.);
label var cocainefull "Cocaine"; 

gen stimulantfull = (crackuse==1 | cocuse==1 | mthause==1); 
replace stimulantfull = . if (crackuse==. & cocuse==. & mthause==.); 
label var stimulantfull "Stimulants"; 

gen heroinfull = (heruse==1 | mdonuse==1); 
replace heroinfull = . if heruse==. & mdonuse==.; 
label var heroinfull "Heroin and Illicit Methadone"; 

gen smoke = (smkgrp==1 | smkgrp==2);
replace smoke=. if smkgrp==.; 

gen drink = (drinkgrp==1 | drinkgrp==2 | drinkgrp==3);
replace drink=. if drinkgrp==.; 

tab drinkgrp, gen(drink); 
gen drink0 = drink1; 
replace drink1 = drink2; 
replace drink2 = drink3; 
replace drink3 = drink4; 
drop drink4; 
label var drink0 "Abstainer"; 
label var drink1 "Light (lt 3 drinks/wk)"; 
label var drink2 "Moderate (3-13 drinks/wk)"; 
label var drink3 "Heavier (gt 13 drinks/wk)"; 

tab smkgrp, gen(smoke);
rename smoke1 smokenvr; 
rename smoke2 smokecrnt; 
rename smoke3 smokefrmr; 
label var smokenvr "Never smoker";
label var smokecrnt "Current smoker"; 
label var smokefrmr "Former smoker"; 

** income bins; 
tab incomeco, gen(inc); 
label var inc1 "Yearly income $<$ 6000"; 
label var inc2 "Yearly income 6001-12000"; 
label var inc3 "Yearly income 12001-18000"; 
label var inc4 "Yearly income 18001-24000"; 
label var inc5 "Yearly income 24001-30000"; 
label var inc6 "Yearly income $>$ 30000"; 

* income X employment; 
forvalues i= 1/6{;
	gen inc`i'emp = inc`i'*employ;
}; 
label var inc1emp "Yearly income $<$ 6000, employed"; 
label var inc2emp "Yearly income 6001-12000, employed"; 
label var inc3emp "Yearly income 12001-18000, employed"; 
label var inc4emp "Yearly income 18001-24000, employed"; 
label var inc5emp "Yearly income 24001-30000, employed"; 
label var inc6emp "Yearly income $>$ 30000, employed"; 


** race dummies; 
gen raceaa = (race==3 | race==4); 
replace raceaa=. if race==.;
label var raceaa "Black";

gen racewhite = (race==1); 
replace racewhite=. if race==.;
label var racewhite "White (Non-Hispanic)";

gen racehisp = (race==2 | race==5); 
replace racehisp=. if race==. ;
label var racehisp "Hispanic"; 

gen raceother = (race==6 | race==7 | race==8); 
replace raceother=. if race==.; 
label var raceother "Other race"; 


/*
gen heterosexual = (sexident==1); 
replace heterosexual=. if sexident<0; 
label var heterosexual "Heterosexual"; 
gen bisexual = (sexident==2); 
replace bisexual=. if sexident<0; 
label var bisexual "Bisexual"; 
gen lesbian = (sexident==3); 
replace lesbian=. if sexident<0; 
label var lesbian "Lesbian"; 
gen othersexid = (sexident==4); 
replace othersexid=. if sexident<0; 
label var othersexid "Other Sexual ID"; 
*/

label var cursmoke "Smoker"; 
label var potuse "Used marijuana SLV"; 
label var crackuse "Used crack SLV"; 
label var cocuse "Used powerded cocaine SLV"; 
label var heruse "Used heroin SLV"; 
label var mdonuse "Used (illicit) methadone SLV"; 
label var mthause "Used methamphetamines SLV"; 
label var odrguse "Used other drug SLV"; 

label var msex6mo "No. male sex prtnr SLV"; 
label var fsex6mo "No. female sex prtnr SLV"; 

label var cesd "Depression score"; 
label var HAARTslv "HAART SLV"; 
label var employ "Employed"; 
label var hsgrad "HS grad"; 
label var nkidslt18 "No. kids live with"; 
label var dobyear "Year DOB"; 
label var year "Year of visit"; 
label var ageatvis "Age"; 
label var agesq "Age squared"; 
label var cd4n "CD4 count";  

gen cd4nsq=cd4n*cd4n; 
label var cd4nsq "CD4 squared"; 

**** HAART available; 
gen HAARTavailable = (date2>d(1september1996) & date2!=.); 
replace HAARTavailable=. if date2==.; 
label var HAARTavailable "HAART available";

/*
gen HAARTavl2 = HAARTavailable; 
bys wihsid: egen firstvisH0 = min(visit) if HAARTavailable==1;
bys wihsid: egen firstvisH = min(firstvisH0);

replace HAARTavl2=1 if visit>firstvisH & HAARTavailable==.;
replace HAARTavl2=0 if visit<firstvisH & HAARTavailable==.;
*/

bys wihsid: egen lastvisbfH0 = max(visit) if HAARTavailable==0; 
bys wihsid: egen lastvisbfH = max(lastvisbfH0); 
drop lastvisbfH0; 

** number of visits since HAART; 
gen vispostHAART = visit - lastvisbfH; 
replace vispostHAART = 0 if HAARTavailable==0; 


/*
** time since HAART; 
* six month bins; 
gen timepostHAART = .; 
replace timepostHAART = 0 if date2<=d(1september1996); 
replace timepostHAART = 1 if (date2>d(1september1996) & date2<=d(1march1997)); 
replace timepostHAART = 2 if (date2>d(1march1997) & date2<=d(1september1997)); 
replace timepostHAART = 3 if (date2>d(1september1997) & date2<=d(1march1998)); 
replace timepostHAART = 4 if (date2>d(1march1998) & date2<=d(1september1998)); 
replace timepostHAART = 5 if (date2>d(1september1998) & date2<=d(1march1999)); 
replace timepostHAART = 6 if (date2>d(1march1999) & date2<=d(1september1999)); 
replace timepostHAART = 7 if (date2>d(1september1999) & date2<=d(1march2000)); 
replace timepostHAART = 8 if (date2>d(1march2000) & date2<=d(1september2000)); 
replace timepostHAART = 9 if (date2>d(1september2000) & date2<=d(1march2001)); 
replace timepostHAART = 10 if (date2>d(1march2001) & date2<=d(1september2001)); 
replace timepostHAART = 11 if (date2>d(1september2001) & date2<=d(1march2002)); 
replace timepostHAART = 12 if (date2>d(1march2002) & date2<=d(1september2002)); 
replace timepostHAART = 13 if (date2>d(1september2002) & date2<=d(1march2003)); 
replace timepostHAART = 14 if (date2>d(1march2003) & date2<=d(1september2003)); 
replace timepostHAART = 15 if (date2>d(1september2003) & date2<=d(1march2004)); 
replace timepostHAART = 16 if (date2>d(1march2004) & date2<=d(1september2004)); 
replace timepostHAART = 17 if (date2>d(1september2004) & date2!=.); 

label var timepostHAART "Time since HAART"; 
label define time1 
	0 "Pre-HAART"
	1 "0- 6 months"
	2 ".5 - 1 year"
	3 "1 - 1.5 years"
	4 "1.5 - 2 years"
	5 "2 - 2.5 years"
	6 "2.5 - 3 years"
	7 "3 - 3.5 years"
	8 "3.5 - 4 years"
	9 "4 - 4.5 years"
	10 "4.5 - 5 years"
	11 "5 - 5.5 years" 
	12 "5.5 - 6 years" 
	13 "6 - 6.5 years" 
	14 "6.5 - 7 years"
	15 "7 - 7.5 years"
	16 "7.5 - 8 years"
	17 "8+ years"; 
label values timepostHAART time1 ;


*** nine month bins; 
gen timepostHAART2 = .;
replace timepostHAART2 = 0 if date2<=d(1september1996); 
replace timepostHAART2 = 1 if (date2>d(1september1996) & date2<=d(1june1997));
replace timepostHAART2 = 2 if (date2>d(1june1997) & date2<=d(1march1998)); 
replace timepostHAART2 = 3 if (date2>d(1march1998) & date2<=d(1december1998));
replace timepostHAART2 = 4 if (date2>d(1december1998) & date2<=d(1september1999)); 
replace timepostHAART2 = 5 if (date2>d(1september1999) & date2<=d(1june2000));
replace timepostHAART2 = 6 if (date2>d(1june2000) & date2<=d(1march2001)); 
replace timepostHAART2 = 7 if (date2>d(1march2001) & date2<=d(1december2001));
replace timepostHAART2 = 8 if (date2>d(1december2001) & date2<=d(1september2002));
replace timepostHAART2 = 9 if (date2>d(1september2002) & date2<=d(1june2003));
replace timepostHAART2 = 10 if (date2>d(1june2003) & date2<=d(1march2004)); 
replace timepostHAART2 = 11 if (date2>d(1march2004) & date2<=d(1december2004));
replace timepostHAART2 = 12 if (date2>d(1december2004) & date2!=.);

*** one year bins; 
gen timepostHAART3 = .; 
replace timepostHAART3 = 0 if date2<=d(1september1996); 
replace timepostHAART3 = 1 if (date2>d(1september1996) & date2<d(1september1997)); 
replace timepostHAART3 = 2 if (date2>d(1september1997) & date2<d(1september1998)); 
replace timepostHAART3 = 3 if (date2>d(1september1998) & date2<d(1september1999)); 
replace timepostHAART3 = 4 if (date2>d(1september1999) & date2<d(1september2000)); 
replace timepostHAART3 = 5 if (date2>d(1september2000) & date2<d(1september2001)); 
replace timepostHAART3 = 6 if (date2>d(1september2001) & date2<d(1september2002)); 
replace timepostHAART3 = 7 if (date2>d(1september2002) & date2<d(1september2003)); 
replace timepostHAART3 = 8 if (date2>d(1september2003) & date2<d(1september2004)); 
replace timepostHAART3 = 9 if (date2>d(1september2004) & date2!=.); 
*/

** lagged HAART available; 
sort wihsid visit; 
bys wihsid: gen HAARTavl_lag=HAARTavailable[_n-1]; 


*** change in cd4 count; 
sort wihsid visit ;
by wihsid: gen cd4l=cd4n[_n-1];
label var cd4l "Lagged CD4 count"; 
gen cd4l2=cd4l*cd4l;
label var cd4l2 "Lagged CD4 squared"; 
by wihsid: gen HAL = HAARTavailable[_n-1];
label var HAL "HAART available lagged"; 

* logged cd4; 
gen lcd4=ln(cd4n); 
label var lcd4 "Logged cd4 count"; 


* rename cd4;
rename cd4n cd4; 
rename cd4nsq cd4sq; 

sort wihsid visit ;
bys wihsid: gen cd41=cd4[_n+1];
label var cd41 "cd4 count at next visit"; 


/*
gen cd412=cd41*cd41;
label var cd412 "cd4 count at next visit squared"; 
gen dcd4=cd4n-cd4l;
label var dcd4 "Change in cd4"; 

gen tsh=(year-1994)+month;
label var tsh "Time since HAART"; 
replace tsh=tsh*HAARTavailable;
replace tsh=tsh-3 if tsh>0;

replace tsh=tsh-1995 if tsh>1996;
replace tsh=0 if tsh==1996;
gen tsh2=tsh*tsh;
label var tsh2 "Time since HAART squared"; 
gen marker = (cd4n==0); 
replace cd4n=1 if cd4n==0; /* trick for logs*/
gen lcd4=ln(cd4n); 
label var lcd4 "Logged cd4 count"; 
gen lcd4sq=ln(cd4nsq);
label var lcd4sq "Log of squred cd4 count"; 
replace cd4n=0 if marker==1; /* change back to 0*/
drop marker; 
*/

* max visit; 
bys wihsid: egen maxvis0=max(visit) if visit!=99 & visit!=88; 
bys wihsid: egen maxvis = max(maxvis0); 
drop maxvis0; 
bys wihsid: egen maxdov=max(date2); 
gen maxvisit_year=year(maxdov); 
gen maxvisit_month=month(maxdov);
tab maxvisit_year maxvisit_month;


* next pd DV; 
sort wihsid visit; 
bys wihsid: gen dva1 = dva[_n+1]; 
label var dva1 "Next period domestic violence"; 

/*
* next pd sex abuse and physical abuse; 
bys wihsid: gen sexabuse1 = sexabuse[_n+1];
label var sexabuse1 "Next period sexual abuse"; 
bys wihsid: gen physabuse1 = physabuse[_n+1];
label var physabuse1 "Next period domestic abuse";
bys wihsid: gen coercion1 = coercion[_n+1]; 
label var coercion1 "Next period coercion";  
*/

** Next period drug use; 
/*
* next pd crack use; 
by wihsid: gen crackuse1=crackuse[_n+1];
label var crackuse1 "Next period crack use"; 
*/
* next pd & previous pd heroin use heroin use; 
by wihsid: gen heruse1 = heruse[_n+1]; 
label var heruse1 "Next period heroin use"; 
* next period cocainefull use; 
bys wihsid: gen cocainefull1 = cocainefull[_n+1]; 
label var cocainefull1 "Next period cocaine use"; 
* next period stimulant use ; 
bys wihsid: gen stimulantfull1 = stimulantfull[_n+1]; 
label var stimulantfull1 "Next period stimulant use";
* next period heroin + methadone use; 
bys wihsid: gen heroinfull1 = heroinfull[_n+1]; 
label var heroinfull1 "Next period heroin or illicit methadone use"; 
* next period cocain use; 
bys wihsid: gen cocuse1 = cocuse[_n+1]; 
label var cocuse1 "Next period powdered cocaine use"; 
* next pd employment; 
by wihsid: gen employ1=employ[_n+1]; 
label var employ1 "Next period employment"; 

/*
* next pd heavy drinking; 
bys wihsid: gen drink31 = drink3[_n+1]; 
label var drink31 "Next period heavy drinking"; 
* next pd hard drug use; 
bys wihsid: gen harddrugs1 = harddrugs[_n+1]; 
label var harddrugs1 "Next period hard drug use"; 
* next pd smokeing; 
bys wihsid: gen smokecrnt1 = smokecrnt[_n+1]; 
*/


* next pd income; 
bys wihsid: gen inc11 = inc1[_n+1]; 
label var inc11 "Next period income lt \$6000/yr"; 

gen inclt12 = inc1==1 | inc2==1; 
bys wihsid: gen inclt121 = inclt12[_n+1]; 
label var inclt121 "Next period income lt \$12000/yr";

* ever employed; 
gen employever=(employ==1 & visit==1); 
bys wihsid: replace employever=1 if employ==1 | employever[_n-1]==1; 
label var employever "Employed ever"; 

bys wihsid: egen employeveryno = max(employever);
label var employeveryno "Yes/No Ever Employed";


* cohort; 
gen cohort=(bsvisit==10);
replace cohort=. if bsvisit==.;
label var cohort "First cohort"; 


* note sample that stays in study until HAART introduced; 
bys wihsid: egen untilHAART = max(HAARTavailable);
label var untilHAART "Stay in survey until HAART"; 



***************** PRE-DETERMINED VARIABLES ******************; 
* income;
bys wihsid: egen maxincpreH1 = max(incomeco) if HAARTavailable==0; 
bys wihsid: egen maxincpreH = max(maxincpreH1); 
label var maxincpreH "Maximum pre-HAART income"; 
drop maxincpreH1;

tab maxincpreH, gen(maxincpreH);
label var maxincpreH1 "Max pre-HAART yearly income $<$ 6000"; 
label var maxincpreH2 "Max pre-HAART yearly income 6001-12000"; 
label var maxincpreH3 "Max pre-HAART yearly income 12001-18000"; 
label var maxincpreH4 "Max pre-HAART yearly income 18001-24000"; 
label var maxincpreH5 "Max pre-HAART yearly income 24001-30000"; 
label var maxincpreH6 "Max pre-HAART yearly income $>$ 30000"; 

* health care provider; 
bys wihsid: egen hcppreH0 = max(hcp6hc) if HAARTavailable==0; 
bys wihsid: egen hcppreH = max(hcppreH0); 
label var hcppreH "HCP pre-HAART"; 
drop hcppreH0; 

bys wihsid: egen avghcppreH0 = mean(nvishc) if HAARTavailable==0; 
bys wihsid: egen avghcppreH = max(nvishc); 
label var avghcppreH "Avg HCP pre-HAART"; 
drop avghcppreH0; 

bys wihsid: egen avgsamehcppreH0 = mean(hdochc) if HAARTavailable==0; 
bys wihsid: egen avgsamehcppreH = max(avgsamehcppreH0); 
label var avgsamehcppreH "Avg same HCP pre-HAART"; 
drop avgsamehcppreH0; 

* married;
bys wihsid: gen marriedpreH1 = (marstat==1 & HAARTavailable==0); 
bys wihsid: egen marriedpreH = max(marriedpreH1);
label var marriedpreH "Married pre-HAART"; 
drop marriedpreH1; 
gen marriedpreHtime=marriedpreH*year; 
label var marriedpreHtime "Married pre-HAART trend"; 
* not married preH ;
gen notmarriedpreH = (marriedpreH==0); 
label var notmarriedpreH "Not married pre-HAART"; 
gen notmarriedpreHtime = notmarriedpreH*year; 
label var notmarriedpreHtime "Not married pre-HAART trend"; 

* employed;
bys wihsid: gen employpreH1 = (employ==1 & HAARTavailable==0);
bys wihsid: egen employpreH = max(employpreH1); 
label var employpreH "Employed pre-HAART"; 
drop employpreH1; 
* not employed;
gen notemploypreH=(employpreH==0); 
label var notemploypreH "Not employed pre-HAART"; 

* dv; 
bys wihsid: gen dvapreH1 = (dva==1 & HAARTavailable==0); 
bys wihsid: egen dvapreH = max(dvapreH1); 
label var dvapreH "Experienced V pre-HAART"; 

* not experience dv; 
gen nodvapreH = (dvapreH==0); 
label var nodvapreH "Did not experience V pre-HAART"; 

* physical abuse; 
bys wihsid: gen physabusepreH1 = (physabuse==1 & HAARTavailable==0); 
bys wihsid: egen physabusepreH = max(physabusepreH1); 
label var physabusepreH "Experienced physical abuse pre-HAART"; 
* not experienced physical abuse; 
gen nophysabspreH = (physabusepreH==0); 
label var nophysabspreH "Did not experience physical abuse pre-HAART"; 

* sex abuse ; 
bys wihsid: gen sexabusepreH1 = (sexabuse==1 & HAARTavailable==0); 
bys wihsid: egen sexabusepreH = max(sexabusepreH1); 
label var sexabusepreH "Experienced sex abuse pre-HAART"; 
* not experienced sexual abuse; 
gen nosexabusepreH = (sexabusepreH!=. & sexabusepreH!=1); 
label var nosexabusepreH "Did not experience sex abuse pre-HAART"; 

* coercion; 
bys wihsid: gen coercionpreH1 = (coercion==1 & HAARTavailable==0);
bys wihsid: egen coercionpreH = max(coercionpreH1); 
label var coercionpreH "Experienced coercion"; 
drop dvapreH1 physabusepreH1 sexabusepreH1 coercionpreH1; 

* ever married; 
bys wihsid: gen marriedever1 = (marstat==1); 
bys wihsid: egen marriedever = max(marriedever1);
label var marriedever "Ever married";  
drop marriedever1; 
* never married; 
gen nevermarriedever = (marriedever!=1 & marriedever!=.); 
label var nevermarriedever "Never married"; 

* highest income ever; 
bys wihsid: egen maxincever = max(incomeco); 
label var maxincever "Max income ever"; 

* dummy variables- calculate Y/N pre HAART (note- just denote whether they ever smoked preH using smoke1);
foreach var in smokecrnt crackuse cocuse potuse heruse harddrugs stimulantfull heroinfull cocainefull drink3{;
bys wihsid: egen `var'preH0 = max(`var') if HAARTavailable==0;
bys wihsid: egen `var'preH = max(`var'preH0) ;
drop `var'preH0;
};
label var smokecrntpreH "Smoke pre_HAART"; 
label var crackusepreH "Crack use pre-HAART"; 
label var cocusepreH "Cocaine (powdered) use pre-HAART"; 
label var potusepreH "Pot use pre-HAART"; 
label var herusepreH "Heroin use pre-HAART"; 
label var harddrugspreH "Hard drugs pre-HAART"; 
label var drink3preH "Heavy drinker pre-HAART"; 
label var cocainefullpreH "Cocaine use pre-HAART"; 
label var stimulantfullpreH "Stimulant use pre-HAART"; 
label var heroinfullpreH "Heroin or Illicit Methadone use pre-HAART"; 

** Ever experience outcomes; 
sort wihsid visit; 
foreach outcome in dva heruse cocainefull {; 
	gen `outcome'ever = `outcome'==1 & visit==1; 
	bys wihsid: replace `outcome'ever = 1 if `outcome'==1 | `outcome'ever[_n-1] ==1;
};	
	

* symptoms; 
foreach var in fever diarrhea memoryprblm numbness weightloss mentalconf nightsweats {; 
	bys wihsid: egen `var'preH0 = max(`var') if HAARTavailable==0; 
	bys wihsid: egen `var'preH = max(`var'preH0); 
	drop `var'preH0; 
	
	bys wihsid: gen `var'1 = `var'[_n+1]; 
}; 
label var feverpreH "Fever pre-HAART"; 
label var memoryprblmpreH "Memory Problems pre-HAART"; 
label var numbnesspreH "Numbness pre-HAART"; 
label var weightlosspreH "Weight Loss pre-HAART"; 
label var mentalconfpreH "Mental Confusion pre-HAART"; 
label var nightsweatspreH "Night Sweats pre-HAART";

label var fever1 "Fever t+1"; 
label var memoryprblm1 "Memory problem t+1"; 
label var numbness1 "Numbness t+1"; 
label var weightloss1 "Weightloss t+1"; 
label var mentalconf1 "Mental confusion t+1"; 
label var nightsweats1 "Night sweats t+1"; 

* count; 
gen symptomcount = fever + memoryprblm + numbness + weightloss + mentalconf + nightsweats;
 
sort wihsid visit;
bys wihsid: gen symptomcount1 = symptomcount[_n+1];

* yes/no; 
gen symptomyn = (symptomcount>0);
replace symptomyn = . if symptomcount==.;

sort wihsid visit;
bys wihsid: gen symptomyn1 = symptomyn[_n+1];

* depression stuff; 
* cesd depressed- cut off is greater than 16; 
gen depressedcesd = cesd>=16; 
replace depressedcesd = . if cesd==.; 
label var depressedcesd "Depressed, cesd score"; 
bys wihsid: egen depressedcesdpreH0 = max(depressedcesd) if HAARTavailable==0; 
bys wihsid: egen depressedcesdpreH = max(depressedcesdpreH0); 
drop depressedcesdpreH0;
label var depressedcesdpreH "Depressed pre-HAART"; 

* avg cesd score; 
bys wihsid: egen cesdavgpreH0 = mean(cesd) if HAARTavailable==0; 
bys wihsid: egen cesdpreH = max(cesdavgpreH0); 
drop cesdavgpreH0; 
label var cesdpreH "Average CES-D Score pre-HAART"; 

gen depressedcesd1 = depressedcesd[_n+1]; 
gen cesd1 = cesd[_n+1]; 

* GENERATE NEW VARS;
* look at cd4 count pre-HAART- both min and max and avg;
gen cd40preH=cd4 if HAARTavailable==0 ;
bys wihsid: egen maxcd4preH = max(cd40preH);
label var maxcd4preH "Maximum CD4 Count pre-HAART"; 
bys wihsid: egen mincd4preH = min(cd40preH);
label var mincd4preH "Minimum CD4 Count pre-HAART"; 
bys wihsid: egen cd4avgpreH = mean(cd40preH); 
label var cd4avgpreH "Average CD4 Count pre-HAART"; 
drop cd40preH;

bys wihsid: egen HAARTeverbinary = max(HAARTever);
label var HAARTeverbinary "Ever on HAART"; 


** HIV+ CD4 count group; 
gen lowcd4=(cohort==1 & mincd4preH<300 & positive==1); 
gen medcd4=(cohort==1 & mincd4preH>=300 & mincd4preH<400 & positive==1);
gen highcd4 = (cohort==1 & mincd4preH>=400 & mincd4preH!=. & positive==1); 

gen cd4group = . ;
replace cd4group=1 if lowcd4==1; 
replace cd4group=2 if medcd4==1; 
replace cd4group=3 if highcd4==1; 

label define cd4 
	1 "Low CD4"
	2 "Treatment Group"
	3 "High CD4"; 
label values cd4group cd4; 


* define treatment group ;
gen targetgrp = (mincd4preH>=300 & mincd4preH<400 & positive==1 & cohort==1);
label var targetgrp "Treatment Group";
gen targetgrpH = targetgrp*HAARTavailable;
label var targetgrpH "Treatment $\times$ HAART";

gen targetgrp2 = (mincd4preH>300 & mincd4preH<400 & positive==1 & cohort==1);
label var targetgrp "Treatment Group";

gen targetgrp3 = (mincd4preH>300 & mincd4preH<=400 & positive==1 & cohort==1);
label var targetgrp "Treatment Group";

** look at death as outcome; 
bys wihsid: egen death = max(outcdth); 

* max vis * death; 
gen maxvisdeath = maxvis*death; 
label var maxvisdeath "Max visit X Death";  

* gen var for being alive; 
gen alive = .;
replace alive = 1 if death==0;
replace alive = 1 if death==1 & visit<maxvisdeath; 
replace alive = 0 if death==1 & visit>=maxvisdeath & visit<=33;
  
 
* generate sample- includes all obs that are not missing dv outcome and basic vars; 
local dva1miss 10,12,14,16,18,20,22,24,26,28,30,32,33; 
gen samp_full=.;
#delimit; 
replace samp_full = 1 if cohort==1 & mincd4preH!=. & ageatvis!=. & race!=. & site!=. & dva1!=. &
HAARTavailable!=. & targetgrp!=. & targetgrpH!=. & dvapreH!=. & cocainefull1!=. & employ1!=. & heruse1!=. &
married!=. & livewithprtnr!=. & widowed!=. & divorced!=. & separated!=. & marstatother!=. &
inc1!=. ;
* note- only two obs have nonmissing dva1 in these visits, so just code to missing; 
replace samp_full = . if inlist(visit,`dva1miss'); 

gen targetsamp = 1 if targetgrp==1 & samp_full==1; 
gen negsamp = 1 if positive==0 & samp_full==1; 
gen healthysamp = 1 if mincd4preH>=400 & mincd4preH!=. & samp_full==1 & positive==1; 
gen sicksamp = 1 if mincd4preH<300 & samp_full==1 & positive==1; 

gen sampgroup = .;
replace sampgroup = 1 if targetsamp==1;
replace sampgroup = 2 if negsamp==1;
replace sampgroup = 3 if healthysamp==1; 
replace sampgroup = 4 if sicksamp==1; 

label define samp 
	1 "Target group"
	2 "Negative sample"
	3 "HIV+ healthy sample"
	4 "HIV+ sick sample"; 
label values sampgroup samp; 

aorder;
order wihsid visit ;

xtset, clear; 

save "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", replace; 

