/* 
T2_preHtrend.do

This file creates Table 2: Test of Equality of Pre-HAART Trends for Papageorge et al. (2019). 
Last updated: 09/13/2019. 
*/


*** Define controls;  
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc /*sitela sitesanfran sitechicago*/
* for AA only, leave out race;
local control0race ageatvis agesq agecube sitebronx sitebrooklyn sitedc /*sitela sitesanfran sitechicago*/



********************************************************************************
****************************    JOINT TESTS     ********************************
********************************************************************************
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

* vars; 
gen preHAART = HAARTavailable==0
gen dovbincentersq = dovbincenter * dovbincenter 

* tell Stata what to dov bin to omit
char dovbin[omit] 2

** Domestic violence; 
** dummies
xi: reg dva1 i.targetgrp*i.dovbin `control0' if (targetsamp==1 | healthysamp==1) , cluster(wihsid)
test  _ItarXdov_1_1  =  _ItarXdov_1_3 = _ItarXdov_1_4
gen pval0 = r(p)
* time trend; 
xi: probit dva1 preHAART##targetgrp##c.dovbincenter `control0'  if (targetsamp==1 | healthysamp==1), cluster(wihsid) 

* quad time; 
xi: probit dva1 preHAART##targetgrp##c.dovbincentersq `control0'  if (targetsamp==1 | healthysamp==1), cluster(wihsid) 


** cocaine use; 
* dummies; 
xi: reg cocainefull1 i.targetgrp*i.dovbin `control0' if (mincd4preH>300 & mincd4preH!=.) & cohort==1 & positive==1 & visit<=33, cluster(wihsid)
test  _ItarXdov_1_1  = _ItarXdov_1_3 = _ItarXdov_1_4
gen pval1 = r(p)


** heroin use; 
* dummies
xi: reg heruse1 i.targetgrp*i.dovbin `control0' if (mincd4preH>300 & mincd4preH!=.) & cohort==1 & positive==1 & visit<=33, cluster(wihsid)
test  _ItarXdov_1_1  =  _ItarXdov_1_3 = _ItarXdov_1_4
gen pval2 = r(p)

*** make a table with p values for test of equality across coeff.; 
keep pval* 

keep if _n==1 /* only need one because pval* is scalar */
gen id = _n /* for reshaping */
reshape long pval, i(id) j(outcome)

label define outcomelab 0 "Domestic Violence" 1 "Cocaine Use" 2 "Heroin Use" 3 "Joint significance"
label values outcome outcomelab

drop id
gen break1 = "&" 
gen break2 = "\\"
order outcome break1 pval break2
format pval %9.3f

save temp.dta, replace





********************************************************************************
************************ JOINT TEST ACROSS OUTCOMES  ***************************
********************************************************************************
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

* vars; 
gen preHAART = HAARTavailable==0
gen dovbincentersq = dovbincenter * dovbincenter 


svyset wihsid 

* tell Stata what to dov bin to omit
char dovbin[omit] 2
xi: svy: probit dva1 i.targetgrp*i.dovbin `control0' if (targetsamp==1 | healthysamp==1)
est store probdva


xi: svy: probit cocainefull1 i.targetgrp*i.dovbin `control0' if (mincd4preH>300 & mincd4preH!=.) & cohort==1 & positive==1 & visit<=33
est store probcoc

xi: svy: probit heruse1 i.targetgrp*i.dovbin `control0' if (mincd4preH>300 & mincd4preH!=.) & cohort==1 & positive==1 & visit<=33
est store probher 

suest probdva probcoc probher

 

#delimit; 
test [probdva_dva1]_ItarXdov_1_1  = [probdva_dva1]_ItarXdov_1_3 = [probdva_dva1]_ItarXdov_1_4 =
[probcoc_cocainefull1]_ItarXdov_1_1  = [probcoc_cocainefull1]_ItarXdov_1_3 = [probcoc_cocainefull1]_ItarXdov_1_4 =
[probher_heruse1]_ItarXdov_1_1  = [probher_heruse1]_ItarXdov_1_3 = [probher_heruse1]_ItarXdov_1_4;

return list; 

gen pval = r(p); 
collapse pval; 

gen outcome = 3;
label values outcome outcomelab; 

gen break1 = "&" ;
gen break2 = "\\";
order outcome break1 pval break2;
format pval %9.3f;

save temp1.dta, replace;

#delimit cr


save temp1.dta, replace


use temp.dta, clear
append using temp1.dta

save "$tabledir\T2_preHtrends.dta", replace

erase temp.dta
erase temp1.dta

