/* 
T3_probits.do

This file creates Table 3: Health, Violence and Drug Use: Probit Coefficients for Papageorge et al. (2019). 
Last updated: 09/13/2019. 
*/


*** Call data
use "$startdir/Estimation/Stata/Datasets/dv_clean.dta", clear


*** Set structure
xtset wihsid visit


*** Define controls
* for full sample 
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/

* for AA only, leave out race
local control0norace ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/
 
 
*** Run regressions for full sample;  
** Domestic Violence; 
probit dva1 HAARTavailable targetgrp targetgrpH if targetsamp ==1 | healthysamp==1, cluster(wihsid)
est2vec T3probit, replace vars(HAARTavailable targetgrp targetgrpH)

probit dva1 HAARTavailable targetgrp targetgrpH `control0' if targetsamp ==1 | healthysamp==1, cluster(wihsid)
est2vec T3probit, name(col2) addto(T3probit)


** Cocaine; 
reg cocainefull1 HAARTavailable targetgrp targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen samp_coc=e(sample) 

probit cocainefull1 HAARTavailable targetgrp targetgrpH if samp_coc==1, cluster(wihsid)
est2vec T3probit, name(col3) addto(T3probit)

probit cocainefull1 HAARTavailable targetgrp targetgrpH `control0' if samp_coc==1, cluster(wihsid)
est2vec T3probit, name(col4) addto(T3probit)

** Heroin; 
reg heruse1 HAARTavailable targetgrp targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen samp_her=e(sample) 

probit heruse1 HAARTavailable targetgrp targetgrpH if samp_her==1, cluster(wihsid)
est2vec T3probit, name(col5) addto(T3probit)

probit heruse1 HAARTavailable targetgrp targetgrpH `control0' if samp_her==1, cluster(wihsid)
est2vec T3probit, name(col6) addto(T3probit)

est2texOWO T3probit, collabels(1 2 3 4 5 6) mark(starb) label dots notabular path($tabledir) levels(90 95 99) fancy preserve replace



*** Run regressions for black women
*** Call data;   
use "$startdir/Estimation/Stata/Datasets/dv_clean.dta", clear

*** Set structure
xtset wihsid visit

*** Keep black women 
keep if raceaa==1

** Domestic violence
probit dva1 HAARTavailable targetgrp targetgrpH if targetsamp ==1 | healthysamp==1, cluster(wihsid)
est2vec T3probitaa, replace vars(HAARTavailable targetgrp targetgrpH)

probit dva1 HAARTavailable targetgrp targetgrpH `control0norace' if targetsamp ==1 | healthysamp==1, cluster(wihsid)
est2vec T3probitaa, name(col2) addto(T3probitaa)

** Cocaine; 
reg cocainefull1 HAARTavailable targetgrp targetgrpH `control0norace' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen samp_coc=e(sample) 

probit cocainefull1 HAARTavailable targetgrp targetgrpH if samp_coc==1, cluster(wihsid)
est2vec T3probitaa, name(col3) addto(T3probitaa)

probit cocainefull1 HAARTavailable targetgrp targetgrpH `control0norace' if samp_coc==1, cluster(wihsid)
est2vec T3probitaa, name(col4) addto(T3probitaa)

** Heroin; 
reg heruse1 HAARTavailable targetgrp targetgrpH `control0norace' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen samp_her=e(sample) 

probit heruse1 HAARTavailable targetgrp targetgrpH if samp_her==1, cluster(wihsid)
est2vec T3probitaa, name(col5) addto(T3probitaa)

probit heruse1 HAARTavailable targetgrp targetgrpH `control0norace' if samp_her==1, cluster(wihsid)
est2vec T3probitaa, name(col6) addto(T3probitaa)

est2texOWO T3probitaa, collabels(1 2 3 4 5 6) mark(starb) label dots notabular path($tabledir) levels(90 95 99) fancy preserve replace
