/*
T4_marginals.do

This file creates Table 4: Health, Violence and Drug Use: Marginal Effects for Papageorge et al. (2019). 
Last updated: 09/13/2019. 
*/



*** Call data
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear


*** Set structure
xtset wihsid visit

*** Define controls; 
* full sample; 
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/
* black women; 
local control0race ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/




******* Full Sample; 
**** Domestic violence 
*** no controls 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH if targetsamp==1 | healthysamp==1, cluster(wihsid)
gen sampA = e(sample)

* r2 
gen r2 = e(r2_p) if sampA==1
label var r2 "Pseudo \$R^{2}\$"

* marginal effect; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store A 

* mean of outcome
gen outcome = dva1 if sampA==1 & HAARTavailable==0 & targetsamp==1
label var outcome "Pre-HAART treatment group mean"

gen outcomeall = dva1 if sampA==1
label var outcomeall "Mean"

estpost su outcome outcomeall r2 if sampA==1
est store A2


*** with controls; 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH `control0' if targetsamp==1 | healthysamp==1, cluster(wihsid)
gen sampB = e(sample) 

* r2 
replace r2 = e(r2_p) if sampB==1

* marginal effect
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store B

* mean of outcome; 
replace outcome = dva1 if sampB==1 & HAARTavailable==0 & targetsamp==1

replace outcomeall = dva1 if sampB==1

estpost su outcome outcomeall r2 if sampB==1
est store B2



**** Cocaine 
*** gen sample; 
reg cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen sampcoc=e(sample)

*** no controls
xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH if sampcoc==1, cluster(wihsid)
gen sampC=e(sample)

* r2; 
replace r2 = e(r2_p) if sampC==1

* marginal 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store C

* mean; 
replace outcome = cocainefull1 if sampC==1 & HAARTavailable==0 & targetgrp==1

replace outcomeall = cocainefull1 if sampC==1


estpost su outcome outcomeall r2 if sampC==1
est store C2

*** with controls
xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `control0' if sampcoc==1, cluster(wihsid)
gen sampD = e(sample)

* r squared; 
replace r2 = e(r2_p) if sampD==1

* margins 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store D

* mean of outcome; 
replace outcome = cocainefull1 if sampD==1 & HAARTavailable==0 & targetgrp==1

replace outcomeall = cocainefull1 if sampD==1


estpost su outcome outcomeall r2 if sampD==1
est store D2


**** Heroin 
*** set sample
reg heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen sampheruse=e(sample)

*** no controls
xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH if sampheruse==1, cluster(wihsid)
gen sampE = e(sample)

* r squared
replace r2 = e(r2_p) if sampE==1

* margins
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store E

* mean of outcome
replace outcome = heruse1 if sampE==1 & targetgrp==1 & HAARTavailable==0

replace outcomeall = heruse1 if sampE==1

estpost su outcome outcomeall r2 if sampE==1
est store E2

*** with controls
xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `control0' if sampheruse==1, cluster(wihsid)
gen sampF = e(sample)

* r squared; 
replace r2 = e(r2_p) if sampF==1

* margins
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store F

* mean of outcome; 
replace outcome = heruse1 if sampF==1 & HAARTavailable==0 & targetgrp==1

replace outcomeall = heruse1 if sampF==1

estpost su outcome outcomeall r2 if sampF==1
est store F2



***** Create the tables
** Marginal effects
esttab A B C D E F using "$tabledir\T4fullsamp.tex", replace label cells(b(star fmt(3)) se(par fmt(3)) p(fmt(3)) r2_p(fmt(2))) star(* 0.10 ** 0.05 *** .01)


** Extra stats
esttab A2 B2 C2 D2 E2 F2 using "$tabledir\T4fullsamp_extrastats.tex", replace label cells(mean(fmt(3)))



est clear

******* Black Sample; 
**** Domestic violence 
*** no controls 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH if (targetsamp==1 | healthysamp==1) & raceaa==1, cluster(wihsid)
gen sampBA = e(sample)

* r2 
replace r2 = e(r2_p) if sampBA==1

* margins 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store A

* mean of outcome
replace outcome = dva1 if sampBA==1 & targetsamp==1 & HAARTavailable==0

replace outcomeall = dva1 if sampBA==1

estpost su outcome outcomeall r2 if sampBA==1
est store A2

*** with controls 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH `control0race' if (targetsamp==1 | healthysamp==1) & raceaa==1, cluster(wihsid)
gen sampBB = e(sample)

* r2 
replace r2 = e(r2_p) if sampBB==1

* margins
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store B

* mean of outcome
replace outcome = dva1 if sampBB==1 & HAARTavailable==0 & targetsamp==1

replace outcomeall = dva1 if sampBB==1


estpost su outcome outcomeall r2 if sampBB==1
est store B2


**** Cocaine 
*** no controls 
reg cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `control0race' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1 & raceaa==1, cluster(wihsid)
gen sampcocaa=e(sample)

xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH if sampcocaa==1, cluster(wihsid)
gen sampBC = e(sample)

* r2 
replace r2 = e(r2_p) if sampBC==1

* margins
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store C

* mean of outcome 
replace outcome = cocainefull1 if sampBC==1 & HAARTavailable==0 & targetgrp==1

replace outcomeall = cocainefull1 if sampBC==1

estpost su outcome outcomeall r2 if sampBC==1
est store C2


*** with controls
xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `control0race' if sampcocaa==1, cluster(wihsid)
gen sampBD = e(sample)

* r2; 
replace r2 = e(r2_p) if sampBD==1

* margins; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store D

* mean of outcome 
replace outcome = cocainefull1 if sampBD==1 & HAARTavailable==0 & targetgrp==1

replace outcomeall = cocainefull1 if sampBD==1

estpost su outcome outcomeall r2 if sampBD==1
est store D2

**** Heroin
*** no controls 
reg heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `control0race' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1 & raceaa==1, cluster(wihsid)
gen sampheruseaa=e(sample)

xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH if sampheruseaa==1, cluster(wihsid)
gen sampBE = e(sample)

* r2 
replace r2 = e(r2_p) if sampBE==1

* margins
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store E

* mean of outcome 
replace outcome = heruse1 if sampBE==1 & HAARTavailable==0 & targetgrp==1

replace outcomeall = heruse1 if sampBE==1


estpost su outcome outcomeall r2 if sampBE==1
est store E2

*** with controls
xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `control0race' if sampheruseaa==1, cluster(wihsid)
gen sampBF = e(sample)

* r2 
replace r2 = e(r2_p) if sampBF==1

* margins
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store F

* mean of outcome 
replace outcome = heruse1 if sampBF==1 & HAARTavailable==0 & targetgrp==1

replace outcomeall = heruse1 if sampBF==1

estpost su outcome outcomeall r2 if sampBF==1 
est store F2

***** Create the tables
** Marginal effects 
esttab A B C D E F using "$tabledir\T4blacksamp.tex", replace label cells(b(star fmt(3)) se(par fmt(3)) p(fmt(3))) star(* 0.10 ** 0.05 *** .01)


esttab A2 B2 C2 D2 E2 F2 using "$tabledir\T4blacksamp_extrastats.tex", replace label cells(mean(fmt(3)))