/*
T6_depressionsymptoms.do

This file creates Table 6: Depression Score and Symptoms for Papageorge et al. (2019). 
Last updated: 09/13/2019. 
*/



* Call data
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

* Set structure
xtset wihsid visit



*** Define controls; 
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/

* for AA only, leave out race;
local control0race ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/




***** Full sample 

*** CESD score (OLS)  
** Gen sample
reg cesd1 HAARTavailable targetgrp targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen cesdsamp=e(sample) 

** Estimate model - without controls
reg cesd1 HAARTavailable targetgrp targetgrpH if cesdsamp==1, cluster(wihsid)
est2vec T6_depressionsymptoms, replace vars(HAARTavailable targetgrp targetgrpH)

* r squared
gen r2 = e(r2) if e(sample)
label var r2 "\$R^{2}\$"

* means
egen meanoutcome = mean(cesd1) if e(sample) & HAARTavailable==0 & targetgrp==1
label var meanoutcome "Pre-HAART treatment group mean"

egen meanoutcomeall = mean(cesd1) if e(sample)
label var meanoutcomeall "Mean"

estpost su meanoutcome meanoutcomeall r2 if e(sample)
est store A

** Estimate model - with controls
reg cesd1 HAARTavailable targetgrp targetgrpH `control0' if cesdsamp==1, cluster(wihsid)
est2vec T6_depressionsymptoms, name(col2) addto(T6_depressionsymptoms)

* r squared
replace r2 = e(r2) if e(sample) 

* means
ereplace meanoutcome = mean(cesd1) if e(sample) & HAARTavailable==0 & targetgrp==1

ereplace meanoutcomeall = mean(cesd1) if e(sample)

estpost su meanoutcome meanoutcomeall r2 if e(sample)
est store B


*** Symptoms (OLS);  
** Gen sample
reg symptomyn1 HAARTavailable targetgrp targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid) 
gen sympsamp=e(sample) 

** Estimate model - without controls
reg symptomyn1 HAARTavailable targetgrp targetgrpH if sympsamp==1, cluster(wihsid)
est2vec T6_depressionsymptoms, name(col3) addto(T6_depressionsymptoms)

* r squared 
replace r2 = e(r2) if e(sample)

* means 
ereplace meanoutcome = mean(symptomyn1) if e(sample) & HAARTavailable==0 & targetgrp==1

ereplace meanoutcomeall = mean(symptomyn1) if e(sample)

estpost su meanoutcome meanoutcomeall r2 if e(sample)
est store C

** Estimate model - with controls
reg symptomyn1 HAARTavailable targetgrp targetgrpH `control0' if sympsamp==1, cluster(wihsid)
est2vec T6_depressionsymptoms, name(col4) addto(T6_depressionsymptoms)

* r squared 
replace r2 = e(r2) if e(sample)

* means
ereplace meanoutcome = mean(symptomyn1) if e(sample) & HAARTavailable==0 & targetgrp==1

ereplace meanoutcomeall = mean(symptomyn1) if e(sample)

estpost su meanoutcome meanoutcomeall r2 if e(sample)
est store D



*** Create table 
est2texOWO T6_depressionsymptoms, collabels(1 2 3 4) mark(starb) label dots notabular path($tabledir) levels(90 95 99) fancy preserve replace

esttab A B C D  using "$tabledir/T6_extrastats.tex", replace label cells(mean(fmt(2 2 3)))




***** Black sample 

*** CESD score (OLS)
** Gen sample
reg cesd1 HAARTavailable targetgrp targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1 & raceaa==1, cluster(wihsid)
gen cesdsampaa=e(sample) 

** Estimate model - without controls
reg cesd1 HAARTavailable targetgrp targetgrpH if cesdsampaa==1, cluster(wihsid)
est2vec T6_depressionsymptomsblack, replace vars(HAARTavailable targetgrp targetgrpH)

* r squared
replace r2 = e(r2) if e(sample)

* means
ereplace meanoutcome = mean(cesd1) if e(sample) & HAARTavailable==0 & targetgrp==1

ereplace meanoutcomeall = mean(cesd1) if e(sample)

estpost su meanoutcome meanoutcomeall r2 if e(sample)
est store AB

** Estimate model - with controls
reg cesd1 HAARTavailable targetgrp targetgrpH `control0' if cesdsampaa==1, cluster(wihsid)
est2vec T6_depressionsymptomsblack, name(col2) addto(T6_depressionsymptomsblack)

* r squared
replace r2 = e(r2) if e(sample)

* means
ereplace meanoutcome = mean(cesd1) if e(sample) & HAARTavailable==0 & targetgrp==1

ereplace meanoutcomeall = mean(cesd1) if e(sample)

estpost su meanoutcome meanoutcomeall r2 if e(sample) 
est store BB


*** CESD score (OLS)
** Gen sample
reg symptomyn1 HAARTavailable targetgrp targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1 & raceaa==1, cluster(wihsid) 
gen sympsampaa=e(sample) 

** Estimate model - without controls
reg symptomyn1 HAARTavailable targetgrp targetgrpH if sympsampaa==1, cluster(wihsid)
est2vec T6_depressionsymptomsblack, name(col3) addto(T6_depressionsymptomsblack)

* r squared
replace r2 = e(r2) if e(sample)

* means
ereplace meanoutcome = mean(symptomyn1) if e(sample) & HAARTavailable==0 & targetgrp==1

ereplace meanoutcomeall = mean(symptomyn1) if e(sample) 

estpost su meanoutcome meanoutcomeall r2 if e(sample)
est store CB

** Estimate model - with controls
reg symptomyn1 HAARTavailable targetgrp targetgrpH `control0' if sympsampaa==1, cluster(wihsid)
est2vec T6_depressionsymptomsblack, name(col4) addto(T6_depressionsymptomsblack)

* r squared 
replace r2 = e(r2) if e(sample)

* means
ereplace meanoutcome = mean(symptomyn1) if e(sample) & HAARTavailable==0 & targetgrp==1

ereplace meanoutcomeall = mean(symptomyn1) if e(sample)

estpost su meanoutcome meanoutcomeall r2 if e(sample)
est store DB

est2texOWO T6_depressionsymptomsblack, collabels(1 2 3 4) mark(starb) label dots notabular path($tabledir) levels(90 95 99) fancy preserve replace

esttab AB BB CB DB  using "$tabledir\T6_extrastatsblack.tex", replace label cells(mean(fmt(2 2 3)))