/* 
This file creates Table A5: Normalized Differences in "Health, Human Capital, and Domestic Violence" by Papageorge et al. 

Last updated: 10/07/2019. 
*/

#delimit; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;

* SET STRUCTURE;
xtset wihsid visit;


*********************************************************************
* STEP 1 : Calculate Normalized Differences; 
*********************************************************************;

*** Control group 1 is negative sample; 
*** Control group 2 is healthy sample; 

** since only looking at pre-HAART outcomes, keep one obs per individual; 

bys wihsid: gen nvals=(_n==1); 
keep if nvals==1; 

egen Nt = sum(targetsamp);
egen Nc1 = sum(negsamp);
egen Nc2 = sum(healthysamp); 

egen Ntaa = sum(targetsamp==1 & raceaa==1); 
egen Nc1aa = sum(negsamp==1 & raceaa==1); 
egen Nc2aa = sum(healthysamp==1 & raceaa==1); 

local predetv raceaa racehisp raceother racewhite maxincpreH maxincpreH1 
maxincpreH2 maxincpreH3 maxincpreH4 maxincpreH5 maxincpreH6 ageatvis sitebronx
sitebrooklyn sitedc sitela /*sitesanfran*/ lths hsgrad collegegrad somecollege 
marriedpreH kidsbl smokecrntpreH
dvapreH cocainefullpreH herusepreH employpreH drink cursmoke hivpostime; 

foreach var in `predetv' {; 

egen mu`var't0 = mean(`var') if targetsamp==1; 
egen mu`var't = max(mu`var't0);
drop mu`var't0; 

egen mu`var'c0 = mean(`var') if negsamp ==1; 
egen mu`var'c1 = max(mu`var'c0);
drop mu`var'c0; 

egen mu`var'c0 = mean(`var') if healthysamp==1; 
egen mu`var'c2 = max(mu`var'c0); 
drop mu`var'c0; 


gen St`var'_i = (`var' - mu`var't)*(`var'-mu`var't) if targetsamp==1;
gen Sc1`var'_i = (`var' - mu`var'c1)*(`var'-mu`var'c1) if negsamp==1;
gen Sc2`var'_i = (`var' - mu`var'c2)*(`var'-mu`var'c2) if healthysamp==1; 

egen St`var'_sum = total(St`var'_i); 
egen Sc1`var'_sum = total(Sc1`var'_i); 
egen Sc2`var'_sum = total(Sc2`var'_i);

gen St`var' = 1/(Nt-1) * St`var'_sum;
gen Sc1`var' = 1/(Nc1-1) * Sc1`var'_sum; 
gen Sc2`var' = 1/(Nc2-1) * Sc2`var'_sum; 


gen D_`var' = .; 
replace D_`var' = (mu`var't - mu`var'c1)/sqrt(St`var'/2 + Sc1`var'/2) if negsamp==1; 
replace D_`var' = (mu`var't - mu`var'c2)/sqrt(St`var'/2 + Sc2`var'/2) if healthysamp==1; 

}; 

** Label to make table easier to make; 
label var D_raceaa "African American";
label var D_racehisp "Hispanic";
label var D_raceother "Other race";
label var D_racewhite "White";
label var D_maxincpreH "Max income pre-HAART"; 
label var D_maxincpreH1 "Max inc pre-HAART $<$ 6000"; 
label var D_maxincpreH2 "Max inc pre-HAART 6001-12000";               
label var D_maxincpreH3 "Max inc pre-HAART 12001-18000";              
label var D_maxincpreH4 "Max inc pre-HAART 18001-24000";             
label var D_maxincpreH5 "Max inc pre-HAART 24001-30000";              
label var D_maxincpreH6 "Max inc pre-HAART $>$ 30000" ;
label var D_marriedpreH "Married pre-HAART"; 
label var D_kidsbl "Lived with kids at baseline"; 
label var D_ageatvis "Age at visit";
label var D_sitebronx "Bronx";
label var D_sitebrooklyn "Brooklyn";
label var D_sitedc "DC";
label var D_sitela "LA";
label var D_lths "Less than HS"; 
label var D_hsgrad "HS graduate"; 
label var D_somecollege "Some college"; 
label var D_collegegrad "College graduate";
label var D_dvapreH "Experienced DV pre-HAART";
label var D_cocainefullpreH "Cocaine use pre-HAART";
label var D_herusepreH "Heroin use pre-HAART";
label var D_employpreH "Employed pre-HAART"; 
label var D_cursmoke "Smokes"; 
label var D_drink "Drinks"; 
label var D_hivpostime "Time since 1$^{st}$ $+$ HIV test"; 


local Dvars D_raceaa D_racehisp D_racewhite D_raceother D_maxincpreH D_maxincpreH1
D_maxincpreH2 D_maxincpreH3 D_maxincpreH4 D_maxincpreH5 D_maxincpreH6 
D_ageatvis D_sitebronx D_sitebrooklyn D_sitedc D_sitela 
D_lths D_hsgrad D_somecollege D_collegegrad D_marriedpreH D_kidsbl 
D_dvapreH D_cocainefullpreH D_herusepreH D_employpreH D_cursmoke D_drink 
D_hivpostime ; 

estpost su `Dvars' if healthysamp==1; 
est store A ;


esttab A using "$tabledir\appendix\TA5_normalizeddiff.tex", replace label cells(mean(fmt(2))) mtitle("HIV+, Healthy Sample" "HIV $-$ Sample");



******************************************************************************
* DOMESTIC VIOLENCE; 
******************************************************************************;
******* HIV+ HEALTHY VS SALIENT GROUP; 
* Define controls ;
local dvhealthylin ageatvis agesq agecube raceaa racehisp raceother sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ dvapreH hivpostime hsgrad 
collegegrad kidsbl;

local dvhealthylinaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela 
/*sitesanfran sitechicago*/ dvapreH hivpostime hsgrad collegegrad kidsbl; 

local dvhealthy ageatvis agesq agecube raceaa racehisp /*raceother*/ sitebronx 
sitebrooklyn sitedc /*sitela sitesanfran sitechicago*/ dvapreH hivpostime hsgrad 
collegegrad kidsbl c.ageatvis#i.raceaa c.ageatvis##i.racehisp 
c.ageatvis##c.hivpostime c.ageatvis##collegegrad c.ageatvis##kidsbl 
c.ageatvis##i.dvapreH i.raceaa##i.hsgrad i.raceaa##i.kidsbl i.racehisp##i.hsgrad
i.racehisp##i.collegegrad i.hsgrad##c.hivpostime i.collegegrad##i.dvapreH
c.hivpostime##i.kidsbl i.dvapreH##i.kidsbl i.racehisp##i.kidsbl 
i.racehisp##i.dvapreH c.hivpostime##i.dvapreH;

local dvhealthyaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc /*sitela 
sitesanfran sitechicago*/ dvapreH hivpostime hsgrad collegegrad kidsbl 
c.ageatvis##c.hivpostime c.ageatvis##collegegrad c.ageatvis##kidsbl 
c.ageatvis##i.dvapreH i.hsgrad##c.hivpostime i.collegegrad##i.dvapreH
c.hivpostime##i.kidsbl i.dvapreH##i.kidsbl c.hivpostime##i.dvapreH;


*** PRE-HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==0; 


set scheme s1mono; 

** full sample; 
teffects ipw (dva) (targetgrp `dvhealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (dva) (targetgrp `dvhealthylin', logit) if flag!=1, vce(robust); 
est store A; 

teffects overlap, legend(label(1 "HIV+ High CD4") label(2 "Treatment Group")) xtitle("Propensity Score");
graph export "$startdir/Estimation/Stata/Dofiles/Gwyn/final/output/figures/FA2_dvlin.pdf", replace; 

teffects ipw (dva) (targetgrp `dvhealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (dva) (targetgrp `dvhealthy', logit) if flag2!=1, vce(robust); 
est store B; 

*** POST HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==1; 

teffects ipw (dva) (targetgrp `dvhealthylinaa', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (dva) (targetgrp `dvhealthylinaa', logit) if flag!=1, vce(robust); 
est store C; 

teffects ipw (dva) (targetgrp `dvhealthyaa', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (dva) (targetgrp `dvhealthyaa', logit) if flag2!=1, vce(robust); 
est store D; 

esttab A B C D using "$tabledir\appendix\TA6_propensitydv.tex",
 replace label cells(b(star fmt(4)) se(par fmt(4))) star(* .1 ** .05 *** .01)
 mtitle("Full Samp: Lin" "Full Samp: Quad" "AA Samp: Lin" "AA Samp: Quad");
 


******************************************************************************
* HEROIN USE; 
******************************************************************************;
*** HIV+ HEALTH VS SALIENT GROUP; 
local herhealthylin ageatvis agesq agecube raceaa racehisp /*raceother*/ sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ herusepreH hsgrad 
collegegrad kidsbl ; 

local herhealthy ageatvis agesq agecube raceaa racehisp /*raceother*/ sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ herusepreH hsgrad 
collegegrad kidsbl hivpostime c.ageatvis##i.raceaa c.ageatvis##i.racehisp 
c.ageatvis##i.herusepreH c.ageatvis##i.kidsbl c.ageatvis##c.hivpostime 
i.raceaa##i.hsgrad i.raceaa##i.kidsbl i.racehisp##i.hsgrad 
i.racehisp##c.hivpostime i.herusepreH##i.kidsbl i.herusepreH##c.hivpostime 
i.hsgrad##c.hivpostime i.kidsbl##c.hivpostime i.raceaa##c.hivpostime 
i.racehisp##i.kidsbl; 

local herhealthylinaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc 
sitela /*sitesanfran sitechicago*/ herusepreH hsgrad collegegrad kidsbl ; 

local herhealthyaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela 
/*sitesanfran sitechicago*/ herusepreH hsgrad collegegrad kidsbl 
hivpostime c.ageatvis##i.herusepreH c.ageatvis##i.kidsbl c.ageatvis##c.hivpostime 
i.herusepreH##i.kidsbl i.herusepreH##c.hivpostime 
i.hsgrad##c.hivpostime i.kidsbl##c.hivpostime ;


*** PRE-HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==0; 

teffects ipw (heruse) (targetgrp `herhealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (heruse) (targetgrp `herhealthylin', logit) if flag!=1, vce(robust); 
est store A; 

teffects ipw (heruse) (targetgrp `herhealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (heruse) (targetgrp `herhealthy', logit) if flag2!=1, vce(robust); 
est store B; 


*** POST HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==1; 

teffects ipw (heruse) (targetgrp `herhealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (heruse) (targetgrp `herhealthylin', logit) if flag!=1, vce(robust); 
est store C; 

teffects ipw (heruse) (targetgrp `herhealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (heruse) (targetgrp `herhealthy', logit) if flag2!=1, vce(robust); 
est store D; 

esttab A B C D using "$tabledir\appendix\TA6_propensityheroin.tex",
 replace label cells(b(star fmt(4)) se(par fmt(4))) star(* .1 ** .05 *** .01)
 mtitle("Linear" "Quadratic" "Linear" "Quadratic");

 


******************************************************************************
* COCAINE USE; 
******************************************************************************;
local cochealthylin ageatvis agesq agecube raceaa racehisp raceother sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ cocainefullpreH hivpostime 
hsgrad collegegrad kidsbl; 

local cochealthy ageatvis agesq agecube raceaa racehisp raceother sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ cocainefullpreH hivpostime 
hsgrad collegegrad kidsbl c.ageatvis##i.raceaa c.ageatvis##i.racehisp 
c.ageatvis##i.cocainefullpreH c.ageatvis##c.hivpostime c.ageatvis##i.kidsbl 
i.raceaa##i.hsgrad i.racehisp##i.cocainefullpreH i.racehisp##i.hsgrad 
i.cocainefullpreH##c.hivpostime i.cocainefullpreH##i.kidsbl 
c.ageatvis##i.collegegrad i.raceaa##i.kidsbl; 

local cochealthylinaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc 
sitela /*sitesanfran sitechicago*/ cocainefullpreH hivpostime hsgrad collegegrad 
kidsbl; 

local cochealthy ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela 
/*sitesanfran sitechicago*/ cocainefullpreH hivpostime hsgrad collegegrad kidsbl 
c.ageatvis##i.cocainefullpreH c.ageatvis##c.hivpostime c.ageatvis##i.kidsbl 
i.cocainefullpreH##c.hivpostime i.cocainefullpreH##i.kidsbl 
c.ageatvis##i.collegegrad ; 

*** PRE-HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==0; 

teffects ipw (cocainefull) (targetgrp `cochealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (cocainefull) (targetgrp `cochealthylin', logit) if flag!=1, vce(robust); 
est store A; 

teffects ipw (cocainefull) (targetgrp `cochealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (cocainefull) (targetgrp `cochealthy', logit) if flag2!=1, vce(robust); 
est store B; 


*** POST HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==1; 

teffects ipw (cocainefull) (targetgrp `cochealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (cocainefull) (targetgrp `cochealthylin', logit) if flag!=1, vce(robust); 
est store C; 

teffects ipw (cocainefull) (targetgrp `cochealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (cocainefull) (targetgrp `cochealthy', logit) if flag2!=1, vce(robust); 
est store D; 

esttab A B C D using "$tabledir\appendix\TA6_propensitycoc.tex",
 replace label cells(b(star fmt(4)) se(par fmt(4))) star(* .1 ** .05 *** .01)
 mtitle("Linear" "Quadratic" "Linear" "Quadratic");

 
